@@ -1,6 +1,6 @@
 /* gtkam-context.c
  *
- * Copyright (C) 2001 Lutz Mller <lutz@users.sourceforge.net>
+ * Copyright  2001 Lutz Mller <lutz@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,8 +18,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include "gtkam-context.h"
+#include "i18n.h"
 
 #include <string.h>
 #include <stdlib.h>
@@ -31,25 +32,6 @@
 #include <gtk/gtksignal.h>
 #include <gtk/gtkvbox.h>
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
-
 #define PARENT_TYPE G_TYPE_OBJECT
 static GObjectClass *parent_class;
 
