@@ -1,6 +1,6 @@
 /* gtkam-gimp.c
  *
- * Copyright (C) 2001 Lutz Mller <urc8@rz.uni-karlsruhe.de>
+ * Copyright  2001 Lutz Mller <lutz@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -17,7 +17,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include <config.h>
+#include "config.h"
 
 #include <stdio.h>
 #include <string.h>
@@ -39,25 +39,7 @@
 #include "gtkam-error.h"
 #include "gtkam-fsel.h"
 #include "gtkam-list.h"
-
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "i18n.h"
 
 #define PLUG_IN_PRINT_NAME "GtkamGimp"
 
@@ -84,14 +66,14 @@ query (void)
 
 	gimp_install_procedure ("gtkam-capture", _("Captures images from "
 		"digital camera"), "Nothing here yet. Patches welcome.",
-		"Lutz Mueller <urc8@rz.uni-karlsruhe.de>", "GPL", VERSION,
+		"Lutz Mueller <lutz@users.sf.net>", "GPL", VERSION,
 		N_("<Toolbox>/File/Acquire/Capture from Camera..."),
 		NULL, GIMP_EXTENSION, ncapture_args, ncapture_return_vals,
 		capture_args, capture_return_vals);
 
 	gimp_install_procedure ("gtkam-load", _("Loads files from digital "
 		"cameras"), "Nothing here yet. Patches welcome.", 
-		"Lutz Mueller <urc8@rz.uni-karlsruhe.de>",
+		"Lutz Mueller <lutz@users.sf.net>",
 		"GPL", VERSION,
 		N_("<Toolbox>/File/Acquire/Load from Camera..."),
 		NULL, GIMP_EXTENSION, nload_args, nload_return_vals,
@@ -207,9 +189,9 @@ get_file (GtkamCamera *camera, const gchar *folder, const gchar *name,
 
 	gp_file_new (&file);
 	c = gtkam_cancel_new (_("Downloading '%s' from '%s'..."), name, folder);
-	gtk_widget_show (c);
+	gtk_widget_show(c);
         result = gp_camera_file_get (camera->camera, folder, name,
-		GP_FILE_TYPE_NORMAL, file, GTKAM_CANCEL (c)->context->context);
+		GP_FILE_TYPE_NORMAL, file, GTKAM_CANCEL(c)->context->context);
 	gp_camera_exit (camera->camera, NULL);
 	switch (result) {
 	case GP_OK:
@@ -223,7 +205,7 @@ get_file (GtkamCamera *camera, const gchar *folder, const gchar *name,
 		return -1;
 	default:
                 gp_file_unref (file);
-		dialog = gtkam_error_new (result, GTKAM_CANCEL (c)->context,
+		dialog = gtkam_error_new (result, GTKAM_CANCEL(c)->context,
 			NULL, _("Could not "
                         "download file '%s' from folder '%s'."), name, folder);
                 gtk_widget_show (dialog);
@@ -237,10 +219,10 @@ get_file (GtkamCamera *camera, const gchar *folder, const gchar *name,
 		*return_vals = values;
 		values[0].type = GIMP_PDB_STATUS;
 		values[0].data.d_status = GIMP_PDB_EXECUTION_ERROR;
-		gtk_object_destroy (GTK_OBJECT (c));
+		gtk_object_destroy (GTK_OBJECT(c));
                 return -1;
         }
-	gtk_object_destroy (GTK_OBJECT (c));
+	gtk_object_destroy (GTK_OBJECT(c));
 
 	gp_file_get_data_and_size (file, &data, &size);
         loader = gdk_pixbuf_loader_new ();
