@@ -1,6 +1,6 @@
 /* gtkam-list.c
  *
- * Copyright (C) 2001 Lutz Mller <urc8@rz.uni-karlsruhe.de>
+ * Copyright  2001 Lutz Mller <lutz@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,27 +18,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include "gtkam-list.h"
-
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "i18n.h"
 
 #include <stdio.h>
 #include <string.h>
@@ -87,6 +69,8 @@ struct _GtkamListPrivate
 
 	GtkItemFactory *factory;
 	GtkTreeIter iter;
+	void *head;
+	void *tail;
 };
 
 #define PARENT_TYPE GTK_TYPE_TREE_VIEW
@@ -311,16 +295,17 @@ gtkam_list_get_zoom_factor (GtkamList *list)
 
 typedef struct _GetThumbnailData GetThumbnailData;
 struct _GetThumbnailData {
+	struct _GetThumbnailData *next;
 	GtkamCamera *camera;
 	gchar *folder;
 	gchar *name;
-	GtkamList *list;
 	GtkTreeIter *iter;
 };
 
 static gboolean
 get_thumbnail_idle (gpointer data)
 {
+        GtkamList *list = GTKAM_LIST (data);
 	GetThumbnailData *d = data;
 	CameraFile *file;
 	GtkWidget *s;
@@ -331,9 +316,13 @@ get_thumbnail_idle (gpointer data)
 	unsigned long fs;
 	gfloat factor;
 
+	d = list->priv->head;
+	if (d == NULL)
+		return (FALSE);
 	s = gtkam_status_new (_("Downloading thumbnail of '%s' from "
 		"folder '%s'..."), d->name, d->folder);
-	g_signal_emit (G_OBJECT (d->list), signals[NEW_STATUS], 0, s);
+
+	g_signal_emit (G_OBJECT (list), signals[NEW_STATUS], 0, s);
 	gp_file_new (&file);
 	result = gp_camera_file_get (d->camera->camera, d->folder, d->name,
 			GP_FILE_TYPE_PREVIEW, file,
@@ -342,69 +331,84 @@ get_thumbnail_idle (gpointer data)
 		gp_camera_exit (d->camera->camera, NULL);
 	if (result >= 0) {
 		gp_file_get_data_and_size (file, &fd, &fs);
+
 		loader = gdk_pixbuf_loader_new ();
 		gdk_pixbuf_loader_write (loader, fd, fs, NULL);
 		gdk_pixbuf_loader_close (loader, NULL);
 		pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
-		gtk_list_store_set (d->list->priv->store, d->iter,
+		gtk_list_store_set (list->priv->store, d->iter,
 				    PREVIEW_ORIG_COLUMN, pixbuf, -1);
-		factor = gtkam_list_get_zoom_factor (d->list);
+		factor = gtkam_list_get_zoom_factor (list);
 		pixbuf = gdk_pixbuf_scale_simple (pixbuf,
 			gdk_pixbuf_get_width (pixbuf) * factor,
 			gdk_pixbuf_get_height (pixbuf) * factor,
 			GDK_INTERP_BILINEAR);
 		g_object_unref (G_OBJECT (loader));
-		gtk_list_store_set (d->list->priv->store, d->iter,
+		
+		gtk_list_store_set (list->priv->store, d->iter,
 				    PREVIEW_COLUMN, pixbuf, -1);
 		gdk_pixbuf_unref (pixbuf);
-	}
-
+	} 
+	
 	gp_file_unref (file);
 	gtk_object_destroy (GTK_OBJECT (s));
 
+	if (result == GP_ERROR_CAMERA_BUSY)
+		return (TRUE);
+
 	g_object_unref (G_OBJECT (d->camera));
 	g_free (d->name);
 	g_free (d->folder);
 	gtk_tree_iter_free (d->iter);
+	list->priv->head = d->next;
 	g_free (d);
 
-	return (FALSE);
+	gtk_widget_destroy (s);
+	
+	if (list->priv->head == NULL)
+		return (FALSE);
+	else
+		return (TRUE);
 }
 
 static gboolean
 show_thumbnails_foreach_func (GtkTreeModel *model, GtkTreePath *path,
                               GtkTreeIter *iter, gpointer data)
 {
-        GtkamList *list = GTKAM_LIST (data);
-        GtkamCamera *camera;
-        gchar *folder, *name;
-        CameraAbilities a;
+	GtkamList *list = GTKAM_LIST (data);
+	GtkamCamera *camera;
+	gchar *folder, *name;
+	CameraAbilities a;
 	GetThumbnailData *d;
 	CameraFileInfo info;
 
-        camera = gtkam_list_get_camera_from_iter (list, iter);
-        folder = gtkam_list_get_folder_from_iter (list, iter);
-        name = gtkam_list_get_name_from_iter (list, iter);
+	camera = gtkam_list_get_camera_from_iter (list, iter);
+	folder = gtkam_list_get_folder_from_iter (list, iter);
+	name = gtkam_list_get_name_from_iter (list, iter);
 
-        gp_camera_get_abilities (camera->camera, &a);
+	gp_camera_get_abilities (camera->camera, &a);
 	gp_camera_file_get_info (camera->camera, folder, name, &info, NULL);
-	if ((a.file_operations & GP_FILE_OPERATION_PREVIEW) &&
-	    info.preview.fields) {
+
+	if (a.file_operations & GP_FILE_OPERATION_PREVIEW) {
 		d = g_new0 (GetThumbnailData, 1);
 		d->camera = camera;
 		g_object_ref (G_OBJECT (camera));
 		d->folder = g_strdup (folder);
 		d->name = g_strdup (name);
 		d->iter = gtk_tree_iter_copy (iter);
-		d->list = list;
-		g_idle_add (get_thumbnail_idle, d);
+		if (list->priv->tail)
+			((GetThumbnailData*) list->priv->tail)->next = d;
+		list->priv->tail = d;
+		if (list->priv->head == NULL)
+			list->priv->head = d;
 	}
+
 	g_free (folder);
 	g_free (name);
 	if (camera->multi)
 		gp_camera_exit (camera->camera, NULL);
 
-        return (FALSE);
+	return (FALSE);
 }
 
 void
@@ -417,6 +421,7 @@ gtkam_list_show_thumbnails (GtkamList *list)
 
         gtk_tree_model_foreach (GTK_TREE_MODEL (list->priv->store),
                                 show_thumbnails_foreach_func, list);
+	g_idle_add (get_thumbnail_idle, list);
 }
 
 void
@@ -736,7 +741,8 @@ action_save (gpointer callback_data, guint callback_action, GtkWidget *widget)
         folder = gtkam_list_get_folder_from_iter (list, &list->priv->iter);
         name   = gtkam_list_get_name_from_iter   (list, &list->priv->iter);
 
-        s = gtkam_save_new ();
+        s = gtkam_save_new (GTK_WINDOW (gtk_widget_get_toplevel(
+						GTK_WIDGET(list) )));
         gtkam_save_add (GTKAM_SAVE (s), camera, folder, name);
         g_free (folder);
         g_free (name);
@@ -893,18 +899,28 @@ on_edited (GtkCellRendererText *cell, const gchar *path,
 
 static GtkItemFactoryEntry mi[] =
 {
-	{"/_View with...", NULL, NULL, 0, "<Branch>"},
-	{"/View with.../Built-in viewer", NULL, action_view, 0, NULL},
+	{N_("/_View with..."), NULL, NULL, 0, "<Branch>"},
+	{N_("/View with.../Built-in viewer"), NULL, action_view, 0, NULL},
 	{"/sep0", NULL, NULL, 0, "<Separator>"},
-	{"/_Info", NULL, action_info, 0, NULL},
+	{N_("/View file _properties"), NULL, action_info, 0, NULL},
 #ifdef HAVE_EXIF
-	{"/_Exif", NULL, action_exif, 0, NULL},
+	{N_("/View _EXIF data"), NULL, action_exif, 0, NULL},
 #endif
 	{"/sep1", NULL, NULL, 0, "<Separator>"},
-	{"/_Save", NULL, action_save, 0, "<StockItem>", GTK_STOCK_SAVE},
-	{"/_Delete", NULL, action_delete, 0, "<StockItem>", GTK_STOCK_DELETE}
+	{N_("/_Save"), NULL, gtkam_list_save_selected, 0, "<StockItem>", GTK_STOCK_SAVE},
+	{N_("/_Delete"), NULL, gtkam_list_delete_selected, 0, "<StockItem>", GTK_STOCK_DELETE}
 };
 
+#ifdef ENABLE_NLS
+
+static gchar *
+translate_func (const gchar *path, gpointer data)
+{
+	return (_(path));
+}
+
+#endif
+
 GtkWidget *
 gtkam_list_new (void)
 {
@@ -925,6 +941,10 @@ gtkam_list_new (void)
 	ag = gtk_accel_group_new ();
 	list->priv->factory = gtk_item_factory_new (GTK_TYPE_MENU, "<popup>",
 						    ag);
+#ifdef ENABLE_NLS
+	gtk_item_factory_set_translate_func (GTK_ITEM_FACTORY (list->priv->factory),
+					translate_func, NULL, NULL);
+#endif
 	gtk_item_factory_create_items (list->priv->factory,
 				       G_N_ELEMENTS (mi), mi, list);
 	g_object_ref (G_OBJECT (list->priv->factory));
@@ -1156,7 +1176,8 @@ gtkam_list_save_common (GtkamList *list, gboolean all)
                 return;
 
         sad.list = list;
-        sad.save = gtkam_save_new ();
+        sad.save = gtkam_save_new (GTK_WINDOW (gtk_widget_get_toplevel(
+						       GTK_WIDGET(list) )));
         sad.all = all;
         gtk_tree_model_foreach (GTK_TREE_MODEL (list->priv->store),
                                 save_foreach_func, &sad);
