@@ -1,16 +1,16 @@
 /* gtkam-main.c
  *
- * Copyright (C) 2001 Lutz Mller <urc8@rz.uni-karlsruhe.de>
+ * Copyright  2001 Lutz Mller <lutz@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful, 
- * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details. 
+ * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
@@ -18,27 +18,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include "gtkam-main.h"
-
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "i18n.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -63,6 +45,7 @@
 #include <gtk/gtkcheckbutton.h>
 #include <gtk/gtkfilesel.h>
 #include <gtk/gtktreeselection.h>
+#include <gtk/gtktreestore.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtkimage.h>
 
@@ -187,6 +170,12 @@ gtkam_main_update_sensitivity (GtkamMain *m)
 	gtk_widget_set_sensitive (
 		gtk_item_factory_get_widget (m->priv->factory,
 			"/File/Save Photos/Selected"), (s != 0));
+	gtk_widget_set_sensitive (
+		gtk_item_factory_get_widget (m->priv->factory,
+			"/File/Delete Photos/All"), (i != 0));
+	gtk_widget_set_sensitive (
+		gtk_item_factory_get_widget (m->priv->factory,
+			"/File/Save Photos/All"), (i != 0));
 	gtk_widget_set_sensitive (
 		gtk_item_factory_get_widget (m->priv->factory, "/Select/All"),
 		(s != i));
@@ -330,6 +319,18 @@ action_add_camera (gpointer callback_data, guint callback_action,
 			G_CALLBACK (on_camera_selected), m);
 }
 
+static void
+action_rescan (gpointer callback_data, guint callback_action,
+		GtkWidget *widget)
+{
+	GtkamMain *m = GTKAM_MAIN (callback_data);
+
+	gtk_tree_store_clear (GTK_TREE_STORE (
+			gtk_tree_view_get_model (GTK_TREE_VIEW (m->priv->tree))));
+	
+	gtkam_tree_load (GTKAM_TREE (m->priv->tree));
+}
+
 static void
 action_view_thumbnails (gpointer callback_data, guint callback_action,
 			GtkWidget *widget)
@@ -366,7 +367,7 @@ action_zoom_out (gpointer callback_data, guint callback_action,
 		 GtkWidget *widget)
 {
 	GtkamMain *m = GTKAM_MAIN (callback_data);
-	
+
 	gtkam_list_zoom_out (GTKAM_LIST (m->priv->list));
 }
 
@@ -383,7 +384,7 @@ static void
 on_folder_selected (GtkamTree *tree, GtkamTreeFolderSelectedData *data,
 		    GtkamMain *m)
 {
-	gtkam_list_add_folder (GTKAM_LIST (m->priv->list), 
+	gtkam_list_add_folder (GTKAM_LIST (m->priv->list),
 			       data->camera, data->folder);
 	gtkam_main_update_sensitivity (m);
 }
@@ -413,6 +414,7 @@ on_tree_new_error (GtkamTree *tree, GtkamTreeErrorData *e, GtkamMain *m)
 	GtkWidget *d;
 
 	d = gtkam_error_new (e->result, e->context, NULL, "%s", e->msg);
+
 	gtk_window_set_transient_for (GTK_WINDOW (d), GTK_WINDOW (m));
 	gtk_widget_show (d);
 }
@@ -470,7 +472,7 @@ action_about (gpointer callback_data, guint callback_action,
 		N_("gtkam is a program that lets you download\n"
 		   "images from many digital cameras. It uses\n"
 		   "libgphoto2. More info is available at\n"
-		   "http://www.gphoto.net.\n"
+		   "http://www.gphoto.org.\n"
 		   "\n"
 		   "Enjoy the wonderful world of gphoto!");
 #ifdef HAVE_GNOME
@@ -496,7 +498,6 @@ action_about (gpointer callback_data, guint callback_action,
 	int n;
 
 	for (n = 0; module_versions[n].name != NULL; n++) {
-		int i;
 		gchar *features;
 		const char **v = NULL;
 		char *name = module_versions[n].name;
@@ -512,11 +513,11 @@ action_about (gpointer callback_data, guint callback_action,
 		features = g_strjoinv(", ", &v[1]);
 
 		if (gcomments == NULL) {
-			gcomments = g_strdup_printf("%s\n\n%s %s with options:\n    %s\n", 
+			gcomments = g_strdup_printf(_("%s\n\n%s %s with options:\n    %s\n"),
 						    _(comments), name, v[0], features);
 		} else {
 			gchar *old = gcomments;
-			gcomments = g_strdup_printf("%s\n%s %s with options:\n    %s\n", 
+			gcomments = g_strdup_printf(_("%s\n%s %s with options:\n    %s\n"),
 						    gcomments, name, v[0], features);
 			free(old);
 		}
@@ -539,7 +540,7 @@ action_about (gpointer callback_data, guint callback_action,
 #endif
 	gtk_window_set_transient_for (GTK_WINDOW (d), GTK_WINDOW (m));
 	gtk_widget_show (d);
-	// FIXME free(gcomments);
+	/* FIXME free(gcomments); */
 }
 
 #undef CHECK_NULL
@@ -585,7 +586,7 @@ void
 gtkam_main_load (GtkamMain *m)
 {
 	g_return_if_fail (GTKAM_IS_MAIN (m));
-	
+
 	gtkam_tree_load (GTKAM_TREE (m->priv->tree));
 }
 
@@ -607,6 +608,14 @@ on_zoom_in_clicked (GtkButton *button, GtkamMain *m)
 	gtkam_list_zoom_in (GTKAM_LIST (m->priv->list));
 }
 
+static void
+on_rescan_clicked (GtkButton *button, GtkamMain *m)
+{
+	gtk_tree_store_clear (GTK_TREE_STORE (
+			gtk_tree_view_get_model (GTK_TREE_VIEW (m->priv->tree))));
+	gtkam_tree_load (GTKAM_TREE (m->priv->tree));
+}
+
 static GtkItemFactoryEntry mi[] =
 {
 	{N_("/_File"), NULL, 0, 0, "<Branch>"},
@@ -639,6 +648,7 @@ static GtkItemFactoryEntry mi[] =
 	{N_("/Select/_None"), NULL, action_select_none, 0, NULL},
 	{N_("/_Camera"), NULL, 0, 0, "<Branch>"},
 	{N_("/Camera/_Add Camera..."), NULL, action_add_camera, 0, NULL},
+	{N_("/Camera/_Rescan"), NULL, action_rescan, 0, "<StockItem>", GTK_STOCK_REFRESH},
 	{N_("/_Help"), NULL, 0, 0, "<Branch>"},
 #ifdef HAVE_GNOME
 	{N_("/Help/_Contents"), NULL, action_help, 0, "<StockItem>",
@@ -653,16 +663,7 @@ static GtkItemFactoryEntry mi[] =
 static gchar *
 translate_func (const gchar *path, gpointer data)
 {
-	gchar *result;
-	GError *e = NULL;
-
-	result = g_locale_to_utf8 (_(path), -1, NULL, NULL, &e);
-	if (e) {
-		g_warning ("Could not convert '%s' to UTF-8: '%s'", path,
-			   e->message);
-		g_error_free (e);
-	}
-	return (result);
+	return (_(path));
 }
 
 #endif
@@ -719,6 +720,8 @@ gtkam_main_new (void)
 	gtk_toolbar_append_widget (GTK_TOOLBAR (t), i, NULL, NULL);
 	g_signal_connect (G_OBJECT (i), "toggled",
 			  G_CALLBACK (on_thumbnails_toggled), m);
+	gtk_toolbar_insert_stock (GTK_TOOLBAR (t), GTK_STOCK_REFRESH,
+		NULL, NULL, G_CALLBACK (on_rescan_clicked), m, -1);
 	gtk_toolbar_insert_stock (GTK_TOOLBAR (t), GTK_STOCK_ZOOM_IN,
 		NULL, NULL, G_CALLBACK (on_zoom_in_clicked), m, -1);
 	gtk_toolbar_insert_stock (GTK_TOOLBAR (t), GTK_STOCK_ZOOM_100,
