@@ -1,6 +1,6 @@
 /* gtkam-mkdir.c
  *
- * Copyright (C) 2001 Lutz Mller <urc8@rz.uni-karlsruhe.de>
+ * Copyright  2001 Lutz Mller <lutz@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -17,8 +17,9 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include <config.h>
+#include "config.h"
 #include "gtkam-mkdir.h"
+#include "i18n.h"
 
 #include <string.h>
 
@@ -36,25 +37,6 @@
 #include "gtkam-error.h"
 #include "gtkam-status.h"
 
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
-
 struct _GtkamMkdirPrivate
 {
 	GtkamCamera *camera;
@@ -246,6 +228,13 @@ gtkam_mkdir_new (GtkamCamera *camera, const gchar *path)
 	gtk_entry_set_text (GTK_ENTRY (entry), _("New directory"));
 	mkdir->priv->entry = GTK_ENTRY (entry);
 
+	button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+	gtk_widget_show (button);
+	g_signal_connect (GTK_OBJECT (button), "clicked",
+			    GTK_SIGNAL_FUNC (on_cancel_clicked), mkdir);
+	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (mkdir)->action_area),
+			   button);
+
 	button = gtk_button_new_from_stock (GTK_STOCK_OK);
 	gtk_widget_show (button);
 	g_signal_connect (GTK_OBJECT (button), "clicked",
@@ -254,12 +243,5 @@ gtkam_mkdir_new (GtkamCamera *camera, const gchar *path)
 			   button);
 	gtk_widget_grab_focus (button);
 
-	button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
-	gtk_widget_show (button);
-	g_signal_connect (GTK_OBJECT (button), "clicked",
-			    GTK_SIGNAL_FUNC (on_cancel_clicked), mkdir);
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (mkdir)->action_area),
-			   button);
-
 	return (GTK_WIDGET (mkdir));
 }
