@@ -1,6 +1,6 @@
 /* gtkam-port.c
  *
- * Copyright (C) 2001 Lutz Mller <urc8@rz.uni-karlsruhe.de>
+ * Copyright  2001 Lutz Mller <lutz@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,30 +18,13 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <gphoto2/gphoto2-port-info-list.h>
 
 #include "gtkam-port.h"
-
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "gtkam-error.h"
+#include "i18n.h"
 
 #include <string.h>
 
@@ -159,11 +142,11 @@ on_ok_clicked (GtkButton *button, GtkamPort *port)
 	path = gtk_entry_get_text (GTK_ENTRY (port->priv->entry_path));
 	index = gp_port_info_list_lookup_path (list, path);
 	gp_port_info_list_free (list);
+
 	if (index < 0) {
-		msg = g_strdup_printf (_("Could not find an io-driver for "
-			"port '%s' ('%s')."), path,
-			gp_result_as_string (index));
-		d = gtkam_close_new (msg);
+		msg = g_strdup_printf (_("The port '%s' could not be found. Please make sure "
+		        "that the port exists."), path);
+		d = gtkam_error_new (index, NULL, GTK_WIDGET (port), msg);
 		g_free (msg);
 		gtk_window_set_transient_for (GTK_WINDOW (d),
 					      GTK_WINDOW (port));
@@ -195,8 +178,8 @@ gtkam_port_new (GtkWidget *opt_window)
 	gtk_container_set_border_width (GTK_CONTAINER (table), 10);
 	gtk_table_set_col_spacings (GTK_TABLE (table), 5);
 
-	label = gtk_label_new (_("Please specify the (extended) path to "
-		"the port you would like to use:"));
+	label = gtk_label_new (_("Please specify the path to "
+		"the port your camera is attached to:"));
 	gtk_widget_show (label);
 	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
@@ -207,13 +190,6 @@ gtkam_port_new (GtkWidget *opt_window)
 	gtk_table_attach_defaults (GTK_TABLE (table), entry, 1, 2, 1, 2);
 	port->priv->entry_path = entry;
 
-	button = gtk_button_new_from_stock (GTK_STOCK_OK);
-	gtk_widget_show (button);
-	g_signal_connect (GTK_OBJECT (button), "clicked",
-			    GTK_SIGNAL_FUNC (on_ok_clicked), port);
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (port)->action_area),
-			   button);
-
 	button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
 	gtk_widget_show (button);
 	g_signal_connect (GTK_OBJECT (button), "clicked",
@@ -221,6 +197,13 @@ gtkam_port_new (GtkWidget *opt_window)
 	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (port)->action_area),
 			   button);
 
+	button = gtk_button_new_from_stock (GTK_STOCK_OK);
+	gtk_widget_show (button);
+	g_signal_connect (GTK_OBJECT (button), "clicked",
+			    GTK_SIGNAL_FUNC (on_ok_clicked), port);
+	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (port)->action_area),
+			   button);
+
 	if (opt_window)
 		gtk_window_set_transient_for (GTK_WINDOW (port),
 					      GTK_WINDOW (opt_window));
