@@ -1,6 +1,6 @@
 /* gtkam-tree.c
  *
- * Copyright (C) 2001 Lutz Mller <urc8@rz.uni-karlsruhe.de>
+ * Copyright  2001 Lutz Mller <lutz@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,27 +18,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include "gtkam-tree.h"
-
-#ifdef ENABLE_NLS
-#  include <libintl.h>
-#  undef _
-#  define _(String) dgettext (PACKAGE, String)
-#  ifdef gettext_noop
-#    define N_(String) gettext_noop (String)
-#  else
-#    define N_(String) (String)
-#  endif
-#else
-#  define textdomain(String) (String)
-#  define gettext(String) (String)
-#  define dgettext(Domain,Message) (Message)
-#  define dcgettext(Domain,Message,Type) (Message)
-#  define bindtextdomain(Domain,Directory) (Domain)
-#  define _(String) (String)
-#  define N_(String) (String)
-#endif
+#include "i18n.h"
 
 #include <stdio.h>
 #include <string.h>
@@ -739,6 +721,7 @@ action_select_camera (gpointer callback_data, guint callback_action,
 	g_object_unref (G_OBJECT (d));
 	gtkam_chooser_set_camera (GTKAM_CHOOSER (d),
 		gtkam_tree_get_camera_from_iter (tree, &tree->priv->iter));
+	gtk_window_set_title (GTK_WINDOW (d), _("Select Camera"));
 	data = g_new0 (CameraSelectedData, 1);
 	data->tree = tree;
 	data->iter = gtk_tree_iter_copy (&tree->priv->iter);
@@ -845,21 +828,31 @@ on_add_camera_activate (GtkMenuItem *item, GtkamTree *tree)
 
 static GtkItemFactoryEntry mi[] =
 {
-	{"/Upload file", NULL, action_upload, 0, NULL},
-	{"/Make directory", NULL, action_mkdir, 0, NULL},
-	{"/Remove directory", NULL, action_rmdir, 0, NULL},
+	{N_("/Upload file..."), NULL, action_upload, 0, NULL},
+	{N_("/Make directory..."), NULL, action_mkdir, 0, NULL},
+	{N_("/Delete directory"), NULL, action_rmdir, 0, NULL},
 	{"/sep1", NULL, NULL, 0, "<Separator>"},
-	{"/Capture", NULL, action_capture, 0, NULL},
-	{"/Preferences", NULL, action_preferences, 0,
+	{N_("/Capture image..."), NULL, action_capture, 0, NULL},
+	{N_("/View camera preferences"), NULL, action_preferences, 0,
 	 "<StockItem>", GTK_STOCK_PREFERENCES},
-	{"/Summary", NULL, action_summary, 0, NULL},
-	{"/Manual", NULL, action_manual, 0, NULL},
-	{"/About", NULL, action_about, 0, NULL},
+	{N_("/View camera summary"), NULL, action_summary, 0, NULL},
+	{N_("/View camera manual"), NULL, action_manual, 0, NULL},
+	{N_("/View driver details"), NULL, action_about, 0, NULL},
 	{"/sep2", NULL, NULL, 0, "<Separator>"},
-	{"/Select Camera", NULL, action_select_camera, 0, NULL},
-	{"/Remove Camera", NULL, action_remove_camera, 0, NULL},
+	{N_("/Select camera..."), NULL, action_select_camera, 0, NULL},
+	{N_("/Remove camera"), NULL, action_remove_camera, 0, NULL},
 };
 
+#ifdef ENABLE_NLS
+
+static gchar *
+translate_func (const gchar *path, gpointer data)
+{
+    return (_(path));
+}
+
+#endif
+
 static gint
 on_button_press_event (GtkWidget *widget, GdkEventButton *event,
 		       GtkamTree *tree)
@@ -877,7 +870,7 @@ on_button_press_event (GtkWidget *widget, GdkEventButton *event,
 			event->x, event->y, &path, NULL, NULL, NULL)) {
 			m = gtk_menu_new ();
 			i = gtk_menu_item_new_with_mnemonic (
-							_("_Add Camera..."));
+							_("_Add camera..."));
 			gtk_widget_show (i);
 			gtk_container_add (GTK_CONTAINER (m), i);
 			g_signal_connect (G_OBJECT (i), "activate",
@@ -896,23 +889,23 @@ on_button_press_event (GtkWidget *widget, GdkEventButton *event,
 
 		/* What operations does the camera support? */
 		w = gtk_item_factory_get_widget (tree->priv->factory,
-						 "/Make directory");
+						 "/Make directory...");
 		gtk_widget_set_sensitive (w,
 			a.folder_operations & GP_FOLDER_OPERATION_MAKE_DIR);
 		w = gtk_item_factory_get_widget (tree->priv->factory,
-						 "/Remove directory");
+						 "/Delete directory");
 		gtk_widget_set_sensitive (w,
 			a.folder_operations & GP_FOLDER_OPERATION_REMOVE_DIR);
 		w = gtk_item_factory_get_widget (tree->priv->factory,
-						 "/Upload file");
+						 "/Upload file...");
 		gtk_widget_set_sensitive (w,
 			a.folder_operations & GP_FOLDER_OPERATION_PUT_FILE);
 		w = gtk_item_factory_get_widget (tree->priv->factory,
-						 "/Preferences");
+						 "/View camera preferences");
 		gtk_widget_set_sensitive (w,
 			a.operations & GP_OPERATION_CONFIG);
 		w = gtk_item_factory_get_widget (tree->priv->factory,
-						 "/Capture");
+						 "/Capture image...");
 		gtk_widget_set_sensitive (w,
 			a.operations & GP_OPERATION_CAPTURE_IMAGE);
 
@@ -977,11 +970,15 @@ gtkam_tree_new (void)
 			  G_CALLBACK (on_button_press_event), tree);
 
 	gtk_tooltips_set_tip (tree->priv->tooltips, GTK_WIDGET (tree),
-		_("Please right-click to access additional menus"), NULL);
+		(_("Please right-click to access additional menus")), NULL);
 
 	ag = gtk_accel_group_new ();
 	tree->priv->factory = gtk_item_factory_new (GTK_TYPE_MENU,
 						    "<popup>", ag);
+#ifdef ENABLE_NLS
+	gtk_item_factory_set_translate_func (GTK_ITEM_FACTORY (tree->priv->factory),
+					translate_func, NULL, NULL);
+#endif
 	gtk_item_factory_create_items (tree->priv->factory, 
 				       G_N_ELEMENTS (mi), mi, tree);
 	g_object_ref (G_OBJECT (tree->priv->factory));
@@ -1103,6 +1100,8 @@ gtkam_tree_load (GtkamTree *tree)
 	gp_port_info_list_new (&il);
 	gp_port_info_list_load (il);
 
+	gtk_object_destroy (GTK_OBJECT (s));
+
 	/* Load settings */
 	for (i = 1; ; i++) {
 		ms = g_strdup_printf ("model-%i", i);
@@ -1170,7 +1169,6 @@ gtkam_tree_load (GtkamTree *tree)
 
 	gp_abilities_list_free (al);
 	gp_port_info_list_free (il);
-	gtk_object_destroy (GTK_OBJECT (s));
 }
 
 void
